/*=========================================================================

  Program:   Visualization Toolkit
  Module:    $RCSfile: vtkImageEuclideanToPolar.h,v $
  Language:  C++
  Date:      $Date: 1998/09/16 21:09:08 $
  Version:   $Revision: 1.5 $
  Thanks:    Thanks to C. Charles Law who developed this class.

Copyright (c) 1993-1995 Ken Martin, Will Schroeder, Bill Lorensen.

This software is copyrighted by Ken Martin, Will Schroeder and Bill Lorensen.
The following terms apply to all files associated with the software unless
explicitly disclaimed in individual files. This copyright specifically does
not apply to the related textbook "The Visualization Toolkit" ISBN
013199837-4 published by Prentice Hall which is covered by its own copyright.

The authors hereby grant permission to use, copy, and distribute this
software and its documentation for any purpose, provided that existing
copyright notices are retained in all copies and that this notice is included
verbatim in any distributions. Additionally, the authors grant permission to
modify this software and its documentation for any purpose, provided that
such modifications are not distributed without the explicit consent of the
authors and that existing copyright notices are retained in all copies. Some
of the algorithms implemented by this software are patented, observe all
applicable patent law.

IN NO EVENT SHALL THE AUTHORS OR DISTRIBUTORS BE LIABLE TO ANY PARTY FOR
DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES ARISING OUT
OF THE USE OF THIS SOFTWARE, ITS DOCUMENTATION, OR ANY DERIVATIVES THEREOF,
EVEN IF THE AUTHORS HAVE BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

THE AUTHORS AND DISTRIBUTORS SPECIFICALLY DISCLAIM ANY WARRANTIES, INCLUDING,
BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
PARTICULAR PURPOSE, AND NON-INFRINGEMENT.  THIS SOFTWARE IS PROVIDED ON AN
"AS IS" BASIS, AND THE AUTHORS AND DISTRIBUTORS HAVE NO OBLIGATION TO PROVIDE
MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS.


=========================================================================*/
// .NAME vtkImageEuclideanToPolar - Converts 2D Euclidean coordinates to polar.
// .SECTION Description
// For each pixel with vector components x,y, this filter outputs 
// theta in component0, and radius in component1.

#ifndef __vtkImageEuclideanToPolar_h
#define __vtkImageEuclideanToPolar_h


#include "vtkImageFilter.h"

class VTK_EXPORT vtkImageEuclideanToPolar : public vtkImageFilter
{
public:
  vtkImageEuclideanToPolar();
  static vtkImageEuclideanToPolar *New() 
    {return new vtkImageEuclideanToPolar;};
  const char *GetClassName() {return "vtkImageEuclideanToPolar";};
  void PrintSelf(ostream& os, vtkIndent indent);

  // Description:
  // Theta is an angle. Maximum specifies when it maps back to 0.
  // ThetaMaximum defaults to 255 instead of 2PI, because unsigned char
  // is expected as input. The output type must be the same as input type.
  vtkSetMacro(ThetaMaximum,float);
  vtkGetMacro(ThetaMaximum,float);
  
protected:
  float ThetaMaximum;
  
  void ThreadedExecute(vtkImageData *inData, vtkImageData *outData,
		       int ext[6], int id);
};

#endif



